@@ -2,7 +2,9 @@ package main
 
 import (
 	"log"
+	"math/rand"
 	"os"
+	"time"
 
 	"github.com/percona/percona-backup-mongodb/e2e-tests/pkg/tests/sharded"
 )
@@ -18,7 +20,7 @@ const (
 	defaultMongoUser = "bcp"
 	defaultMongoPass = "test1234"
 
-	dockerSocket = "unix:///var/run/docker.sock"
+	dockerURI = "tcp://docker-host:2375"
 )
 
 type bcpTyp string
@@ -44,6 +46,8 @@ func main() {
 	}
 	log.Println("Backup Type:", bcpT)
 
+	rand.Seed(time.Now().UnixNano())
+
 	typ := testTyp(os.Getenv("TESTS_TYPE"))
 	switch typ {
 	case testsUnknown, testsSharded:
@@ -66,7 +70,7 @@ func runRS(mUser, mPass string, bcpT bcpTyp) {
 		Shards: map[string]string{
 			"rs1": allTheNetworks,
 		},
-		DockerSocket: dockerSocket,
+		DockerURI:    dockerURI,
 		PbmContainer: "pbmagent_rs101",
 	})
 
@@ -89,7 +93,7 @@ func runRemapping(mUser, mPass string) {
 			Shards: map[string]string{
 				"rs1": allTheNetworksRS1,
 			},
-			DockerSocket: dockerSocket,
+			DockerURI:    dockerURI,
 			PbmContainer: "pbmagent_rs101",
 		}),
 		Recipient: sharded.New(sharded.ClusterConf{
@@ -99,7 +103,7 @@ func runRemapping(mUser, mPass string) {
 			Shards: map[string]string{
 				"rs2": allTheNetworksRS2,
 			},
-			DockerSocket: dockerSocket,
+			DockerURI:    dockerURI,
 			PbmContainer: "pbmagent_rs201",
 		}),
 		Remapping: map[string]string{"rs2": "rs1"},
@@ -116,7 +120,7 @@ func runSharded(mUser, mPass string, bcpT bcpTyp) {
 			"rs1": "mongodb://" + mUser + ":" + mPass + "@rs101:27017/",
 			"rs2": "mongodb://" + mUser + ":" + mPass + "@rs201:27017/",
 		},
-		DockerSocket: dockerSocket,
+		DockerURI:    dockerURI,
 		PbmContainer: "pbmagent_rs101",
 	})
 
