@@ -6,16 +6,14 @@ import (
 	"math/rand"
 	"time"
 
-	"github.com/pkg/errors"
 	"go.mongodb.org/mongo-driver/bson"
 	"go.mongodb.org/mongo-driver/bson/primitive"
 	"go.mongodb.org/mongo-driver/mongo"
 	"go.mongodb.org/mongo-driver/mongo/options"
-	"go.mongodb.org/mongo-driver/mongo/readconcern"
-	"go.mongodb.org/mongo-driver/mongo/readpref"
-	"go.mongodb.org/mongo-driver/mongo/writeconcern"
 
-	"github.com/percona/percona-backup-mongodb/pbm"
+	"github.com/percona/percona-backup-mongodb/pbm/connect"
+	"github.com/percona/percona-backup-mongodb/pbm/errors"
+	"github.com/percona/percona-backup-mongodb/pbm/topo"
 )
 
 type Mongo struct {
@@ -24,35 +22,12 @@ type Mongo struct {
 }
 
 func NewMongo(ctx context.Context, connectionURI string) (*Mongo, error) {
-	cn, err := connect(ctx, connectionURI, "e2e-tests")
+	cn, err := connect.MongoConnect(ctx, connectionURI, &connect.MongoConnectOptions{AppName: "e2e-tests"})
 	if err != nil {
 		return nil, errors.Wrap(err, "connect")
 	}
 
-	return &Mongo{
-		cn:  cn,
-		ctx: ctx,
-	}, nil
-}
-
-func connect(ctx context.Context, uri, appName string) (*mongo.Client, error) {
-	client, err := mongo.Connect(ctx,
-		options.Client().ApplyURI(uri).
-			SetAppName(appName).
-			SetReadPreference(readpref.Primary()).
-			SetReadConcern(readconcern.Majority()).
-			SetWriteConcern(writeconcern.Majority()),
-	)
-	if err != nil {
-		return nil, errors.Wrap(err, "mongo connect")
-	}
-
-	err = client.Ping(ctx, nil)
-	if err != nil {
-		return nil, errors.Wrap(err, "mongo ping")
-	}
-
-	return client, nil
+	return &Mongo{cn: cn, ctx: ctx}, nil
 }
 
 const (
@@ -280,8 +255,8 @@ func (m *Mongo) GetCounters() ([]Counter, error) {
 	return data, nil
 }
 
-func (m *Mongo) GetNodeInfo() (*pbm.NodeInfo, error) {
-	inf := &pbm.NodeInfo{}
+func (m *Mongo) GetNodeInfo() (*topo.NodeInfo, error) {
+	inf := &topo.NodeInfo{}
 	err := m.cn.Database("test").RunCommand(m.ctx, bson.M{"isMaster": 1}).Decode(inf)
 	if err != nil {
 		return nil, errors.Wrap(err, "run mongo command")
