@@ -10,7 +10,7 @@ import (
 	"golang.org/x/mod/semver"
 
 	pbmt "github.com/percona/percona-backup-mongodb/e2e-tests/pkg/pbm"
-	"github.com/percona/percona-backup-mongodb/pbm"
+	"github.com/percona/percona-backup-mongodb/pbm/defs"
 )
 
 type scounter struct {
@@ -26,11 +26,11 @@ func lt(t1, t2 primitive.Timestamp) bool {
 	return t1.Compare(t2) < 0
 }
 
-func (c *Cluster) BackupBoundsCheck(typ pbm.BackupType, mongoVersion string) {
+func (c *Cluster) BackupBoundsCheck(typ defs.BackupType, mongoVersion string) {
 	inRange := lte
 	backup := c.LogicalBackup
 	restore := c.LogicalRestore
-	if typ == pbm.PhysicalBackup {
+	if typ == defs.PhysicalBackup {
 		backup = c.PhysicalBackup
 		restore = c.PhysicalRestore
 
@@ -56,14 +56,14 @@ func (c *Cluster) BackupBoundsCheck(typ pbm.BackupType, mongoVersion string) {
 
 	bcpName := backup()
 
-	c.BackupWaitDone(bcpName)
+	c.BackupWaitDone(context.TODO(), bcpName)
 	time.Sleep(time.Second * 1)
 
 	for _, c := range counters {
 		c.cancel()
 	}
 
-	bcpMeta, err := c.mongopbm.GetBackupMeta(bcpName)
+	bcpMeta, err := c.mongopbm.GetBackupMeta(context.TODO(), bcpName)
 	if err != nil {
 		log.Fatalf("ERROR: get backup '%s' metadata: %v\n", bcpName, err)
 	}
@@ -74,7 +74,7 @@ func (c *Cluster) BackupBoundsCheck(typ pbm.BackupType, mongoVersion string) {
 		c.bcheckClear(name, shard)
 	}
 
-	restore(bcpName)
+	restore(context.TODO(), bcpName)
 
 	for name, shard := range c.shards {
 		c.bcheckCheck(name, shard, <-counters[name].data, bcpMeta.LastWriteTS, inRange)
